==> risk-center-api-0.5.4-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/RiskSlotReviewReq.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

@ApiModel
public class RiskSlotReviewReq implements Serializable {

    private static final long serialVersionUID = 443808346390669900L;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getReviewStatus() {
        return reviewStatus;
    }

    public void setReviewStatus(Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }

    public int getLimit() {
        return limit;
    }

    public void setLimit(int limit) {
        this.limit = limit;
    }

    public int getOffset() {
        return offset;
    }

    public void setOffset(int offset) {
        this.offset = offset;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getDiff() {
        return diff;
    }

    public void setDiff(Integer diff) {
        this.diff = diff;
    }

    @ApiModelProperty("主键ID")
    private Long advertId;

    @ApiModelProperty("资源审核状态 0-待审核 1-拒绝 2-通过")
    private Integer reviewStatus;

    @ApiModelProperty("分也开始处")
    private int limit;

    @ApiModelProperty("分页长度")
    private int offset;

    @ApiModelProperty("开始时间")
    private String startTime;

    @ApiModelProperty("结束时间")
    private String endTime;

    @ApiModelProperty("差异度")
    private Integer diff;

}

==> risk-center-api-0.5.42-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/req/RiskSlotReviewReq.java <==
package cn.com.duiba.tuia.risk.center.api.dto.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

@ApiModel
public class RiskSlotReviewReq implements Serializable {

    private static final long serialVersionUID = 443808346390669900L;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getReviewStatus() {
        return reviewStatus;
    }

    public void setReviewStatus(Integer reviewStatus) {
        this.reviewStatus = reviewStatus;
    }

    public int getLimit() {
        return limit;
    }

    public void setLimit(int limit) {
        this.limit = limit;
    }

    public int getOffset() {
        return offset;
    }

    public void setOffset(int offset) {
        this.offset = offset;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getDiff() {
        return diff;
    }

    public void setDiff(Integer diff) {
        this.diff = diff;
    }

    @ApiModelProperty("主键ID")
    private Long advertId;

    @ApiModelProperty("资源审核状态 0-待审核 1-拒绝 2-通过")
    private Integer reviewStatus;

    @ApiModelProperty("分也开始处")
    private int limit;

    @ApiModelProperty("分页长度")
    private int offset;

    @ApiModelProperty("开始时间")
    private String startTime;

    @ApiModelProperty("结束时间")
    private String endTime;

    @ApiModelProperty("差异度")
    private Integer diff;

    @ApiModelProperty("差异排序 0-升序，1-降序")
    private Integer diffSort;

    public Integer getDiffSort() {
        return diffSort;
    }

    public void setDiffSort(Integer diffSort) {
        this.diffSort = diffSort;
    }
}
